
--[[ Configuration functions ]]--

local importFormats = {
	"AskMrRobot", "Pawn"
}

local trinketClauseCategories = { "All", "Melee", "Ranged", "Healer"}

local ItemScoreConfig = {}
ItemScore.ItemScoreConfig = ItemScoreConfig

function ItemScore:InitOptions()
	
	ItemScoreConfig.selectedSet = self:GetDefaultSet()
	
	local importOptions = {
		desc = "Import",
		name = "Import",
		type = "group",
		handler = ItemScoreConfig,
		order = 20,
		
		args = {
			format = {
				type = "select",
				style = "dropdown",
				name = "Format",
				order = 10,
				get = "GetImportFormat",
				set = "SetImportFormat",
				values = importFormats,
			},
			name = {
				type = "input",
				name = "Name",
				order = 20,
				get = "GetImportName",
				set = "SetImportName",
			},
			codeHeader = {
				type = "header",
				name = "Code",
				order = 25,
			},
			code = {
				type = "input",
				name = "Code",
				width = "full",
				order = 30,
				multiline = true,
				get = "GetImportCode",
				set = "SetImportCode",
			},
			import = {
				type = "execute",
				name = "Import",
				func = "ImportScoreSet",
			},
		},
	}
	
	local exportOptions = {
		desc = "Export",
		name = "Export",
		type = "group",
		handler = ItemScoreConfig,
		order = 30,
		
		args = {
			format = {
				type = "select",
				style = "dropdown",
				name = "Format",
				order = 10,
				get = "GetExportFormat",
				set = "SetExportFormat",
				values = importFormats,
			},
			scoreSets = {
				type = "select",
				style = "dropdown",
				name = "Export ItemScore set",
				order = 20,
				values = {},
				get = "GetExportSet",
				set = "SetExportSet",
			},
			codeHeader = {
				type = "header",
				name = "Code",
				order = 25,
			},
			code = {
				type = "input",
				name = "Code",
				width = "full",
				order = 30,
				multiline = true,
				get = "GetExportCode",
			},
		},
	}
	
	local scoreSetOptions = {
		desc = "Score Sets",
		name = "Score Sets",
		type = "group",
		order = 10,
		handler = ItemScoreConfig,
		
		args = {
			scoreSets = {
				type = "select",
				style = "dropdown",
				name = "ItemScore set",
				order = 10,
				values = {},
				get = "GetSelectedSet",
				set = "SetSelectedSet",
			},
			operationHeader = {
				type = "header",
				name = "Score Set Operations",
				order = 15,
			},
			newName = {
			    type = "input",
			    name = "Name",
			    order = 20,
			    get = "GetNewName",
			    set = "SetNewName",
			},
			newSet = {
			    type = "execute",
			    name = "New",
			    order = 30,
			    func = "CreateNewSet",
			    width = "half",
			},
			copySet = {
			    type = "execute",
			    name = "Copy",
			    order = 40,
			    func = "CopySet",
			    width = "half",
			},
			renameSet = {
				type = "execute",
			    name = "Rename",
			    order = 50,
			    func = "RenameSet",
			    width = "half",
			},
			deleteSet = {
			    type = "execute",
			    name = "Delete",
			    order = 60,
			    func = "DeleteSet",
			    width = "half",
			},
			detailsHeader = {
				type = "header",
				name = "Score Set Options",
				order = 65,
			},
			setEnabled = {
				type = "toggle",
				name = "Display",
				order = 70,
				get = "GetEnabled",
				set = "SetEnabled",
				width = "half",
			},
			setParent = {
				type = "select",
				style = "dropdown",
				name = "Parent set",
				order = 75,
				values = {},
				get = "GetParent",
				set = "SetParent",
			},
			--[[trinketHeader = {
				type = "header",
				name = "Trinket Options",
				order = 76,
			},]]--
			setTrinketCalc = {
				type = "toggle",
				name = "Calculate Trinket effects",
				order = 77,
				get = "GetTrinketCalc",
				set = "SetTrinketCalc",
			},
			categories = {
				type = "multiselect",
				name = "Trinket Categories",
				order = 78,
				get = "GetScoreSetCategories", 
				set = "SetScoreSetCategories",
				values = trinketClauseCategories,
				width = "half",
			},
			--[[detailsHeader = {
				type = "header",
				name = "Set Display Options",
				order = 79,
			},]]--
			setPrecision = {
				type = "input",
			    name = "Precision",
			    order = 80,
			    get = "GetPrecision",
			    set = "SetPrecision",
			    width = "half",
			},
			setColour = {
				type = "color",
				name = "Colour",
				order = 90,
				get = "GetColour",
				set = "SetColour",
				width = "half",
			},
			setPattern = {
				type = "input",
			    name = "Display text",
			    desc = "%n - name, %a - score, %d - difference, %p - percent difference",
			    order = 100,
			    get = "GetPattern",
			    set = "SetPattern",
			},
			exampleText = {
				type = "description",
				name = "",
				order = 110,
			},
			statTable = {
				name = "Stat scores",
				type = "group",
				order = 120,
				args = {},
				width = "half",
			},
			availableStats = {
				name = "Available stats",
				type = "group",
				order = 130,
				args = {},
				width = "half",
			}
		},
	}
	
	local trinketOptions = {
		desc = "Trinkets",
		name = "Trinkets",
		type = "group",
		handler = ItemScoreConfig,
		order = 40,
		
		args = {
			trinketUptime = {
				type = "toggle",
				name = "Show trinket uptime",
				order = 10,
				get = "GetShowTrinketUptime",
				set = "SetShowTrinketUptime",
			},
			trinketEffect = {
				type = "toggle",
				name = "Show trinket stat adjustment",
				order = 20,
				get = "GetShowTrinketEffect",
				set = "SetShowTrinketEffect",
			},
			clause = {
				name = "Add clause",
				type = "input",
				set = "AddClause",
				width = "full",
				order = 30,
			}, 
			allClauseTable = {
				name = "All",
				type = "group",
				order = 40,
				args = {},
				--width = "double",
			},
			meleeClauseTable = {
				name = "Melee",
				type = "group",
				order = 50,
				args = {},
				--width = "double",
			},
			rangedClauseTable = {
				name = "Ranged",
				type = "group",
				order = 60,
				args = {},
				--width = "double",
			},
			healerClauseTable = {
				name = "Healer",
				type = "group",
				order = 70,
				args = {},
				--width = "double",
			},
			disabledClauseTable = {
				name = "Disabled",
				type = "group",
				order = 80,
				args = {},
				--width = "double",
			},
			availableClauses = {
				name = "Clauses seen",
				type = "group",
				order = 90,
				args = {},
				width = "double",
			}
		},
	}
	
	self.options = {
		desc = "ItemScore",
		type = "group",
		childGroups = "tab",
		order = 10,
		handler = ItemScoreConfig,
		args = {importOptions = importOptions, scoreSetOptions = scoreSetOptions, exportOptions = exportOptions, trinketOptions = trinketOptions}
	}
	
	ItemScoreConfig.scoreSetOptionsArgs = scoreSetOptions.args
	ItemScoreConfig.scoreSetValues = ItemScoreConfig.scoreSetOptionsArgs.scoreSets.values
	ItemScoreConfig.setParentValues = ItemScoreConfig.scoreSetOptionsArgs.setParent.values
	ItemScoreConfig.exportValues = exportOptions.args.scoreSets.values
	ItemScoreConfig.exampleText = ItemScoreConfig.scoreSetOptionsArgs.exampleText
	ItemScoreConfig.trinketOptionsArgs = trinketOptions.args
	
	ItemScoreConfig:UpdateStatTable()
	ItemScoreConfig:UpdateSetLists()
	ItemScoreConfig:UpdateClauseTable()
end

function ItemScore:RegisterSlashCommands()
	self:RegisterChatCommand('itemscore', 'OnCmd')
end

function ItemScoreConfig:UpdateStatTable()
	optionList = self.scoreSetOptionsArgs
	local scoreSet = ItemScore:GetScoreSet(self.selectedSet)

	-- if nothing selected, clear out the table
	if not scoreSet then
		for i in pairs(optionList.statTable.args) do
			if optionList.statTable.args[i].type == "group" then
				optionList.statTable.args[i] = nil
			end
		end
		for i in pairs(optionList.availableStats.args) do
			if optionList.availableStats.args[i].type == "group" then
				optionList.availableStats.args[i] = nil
			end
		end
	else
		for i in pairs(scoreSet.info) do
			local capVal = ""
			
			if scoreSet.info[i].cap and scoreSet.info[i].cap ~= -1 then
				capVal = " (<=" .. scoreSet.info[i].cap .. ")"
			end
			
			if not optionList.statTable.args[i] then
			 
				local options = {
					score = {
						name = "Score",
						type = "input",
						order = 110,
						set = "SetScore",
						get = "GetScore",
						arg = i					
					},
					cap = {
						name = "Cap",
						type = "input",
						order = 200,
						set = "SetCap",
						get = "GetCap",
						arg = i
					},
					remove = {
						type = "execute",
					    name = "Remove",
					    order = 210,
					    func = "RemoveStat",
					    arg = i,
					}
				}
							
				-- quietly remove stat if its not supported
				if not ItemScore.supportedStats[i] then
					scoreSet.info[i] = nil
				else
					optionList.statTable.args[i] = {
						name = ItemScore.supportedStats[i] .. " - " .. scoreSet.info[i].score .. capVal,
						type = "group",
						width = "half",
						args = options
					}
				end
			else
				-- just update the name
				optionList.statTable.args[i].name = ItemScore.supportedStats[i] .. " - " .. scoreSet.info[i].score .. capVal
			end
		end
		
		-- remove stats that are no longer in the list
		for i in pairs(optionList.statTable.args) do
			if not scoreSet.info[i] then
				optionList.statTable.args[i] = nil
			end
		end
		
		-- now populate another list with stats that aren't in the set
		for i in pairs(ItemScore.supportedStats) do
			if not scoreSet.info[i] then
				local options = {
					add = {
						type = "execute",
					    name = "Add",
					    order = 210,
					    func = "AddStat",
					    arg = i,
					}
				}
						
				optionList.availableStats.args[i] = {
					name = ItemScore.supportedStats[i],
					type = "group",
					width = "half",
					args = options
				}
			end
		end
		
		-- remove stats that are in the set
		for i in pairs(optionList.availableStats.args) do
			if scoreSet.info[i] then
				optionList.availableStats.args[i] = nil
			end
		end
	end
end

function ItemScoreConfig:UpdateSetLists()
	ItemScoreConfig:UpdateSetList(self.scoreSetValues, nil, false)
	ItemScoreConfig:UpdateSetList(self.setParentValues, self.selectedSet, true)
	ItemScoreConfig:UpdateSetList(self.exportValues, nil, false)
end

function ItemScoreConfig:UpdateSetList(optionList, ignoreSet, addEmpty)
	local setList = ItemScore:GetScoreSets()
	
	-- add new sets that aren't in optionList
	for i in pairs(setList) do
		if not optionList[i] then
			optionList[i] = i
		end
	end
	
	-- remove from optionList spells that aren't in spellList
	for i in pairs(optionList) do
		if not setList[i] then
			optionList[i] = nil
		end
	end
	
	if ignoreSet then
	    optionList[ignoreSet] = nil
	end
	
	self:UpdateExampleText(self.exampleText, self.selectedSet)
	
	if addEmpty then
	    optionList[""] = ""
	end
end

function ItemScoreConfig:UpdateExampleText()
	if not self.selectedSet then
		self.exampleText.name = ""
		return
	end
	
	local score = 123.456789
	local equippedScore = 125.567891
	
	self.exampleText.name = ItemScore:MakeTooltipText(ItemScore:GetScoreSet(self.selectedSet), score, score, equippedScore, equippedScore)
end

local function addToClauseList(table, clause)
	local shortenedName = clause
	local NAME_LIMIT = 20
	if string.len(shortenedName) > NAME_LIMIT then
		shortenedName = string.sub(shortenedName, 0, NAME_LIMIT) .. "..."
	end
	
	local options = {
		clause = {
			type = "input",
			name = "Modify clause",
			order = 5,
			arg = clause,
			set = "RenameClause",
			width = "full",
			get = function(info) return info.arg end, 
		},
		categories = {
			type = "multiselect",
			name = "Categories",
			order = 6,
			arg = clause,
			get = "GetClauseCategories", 
			set = "SetClauseCategories",
			values = trinketClauseCategories,
		},
		remove = {
			type = "execute",
		    name = "Remove",
		    order = 10,
		    func = "RemoveClause",
		    arg = clause,
		},
	}
	
	table.args[clause] = {
		name = shortenedName,
		type = "group",
		desc = clause,
		args = options,
	}
end

function ItemScoreConfig:UpdateClauseTable()
	optionList = self.trinketOptionsArgs
	
	local trinketClauses = ItemScore:GetTrinketClauses()
	for i in pairs(optionList.allClauseTable.args) do
		if not trinketClauses[i] or not trinketClauses[i]["All"] then
			optionList.allClauseTable.args[i] = nil
		end
	end
	for i in pairs(optionList.meleeClauseTable.args) do
		if not trinketClauses[i] or not trinketClauses[i]["Melee"] then
			optionList.meleeClauseTable.args[i] = nil
		end
	end
	for i in pairs(optionList.rangedClauseTable.args) do
		if not trinketClauses[i] or not trinketClauses[i]["Ranged"] then
			optionList.rangedClauseTable.args[i] = nil
		end
	end
	for i in pairs(optionList.healerClauseTable.args) do
		if not trinketClauses[i] or not trinketClauses[i]["Healer"] then
			optionList.healerClauseTable.args[i] = nil
		end
	end
	for i in pairs(optionList.disabledClauseTable.args) do
		if not trinketClauses[i] or trinketClauses[i]["All"] or 
			   trinketClauses[i]["Melee"] or trinketClauses[i]["Ranged"] or 
			   trinketClauses[i]["Healer"] then
			optionList.disabledClauseTable.args[i] = nil
		end
	end
	
	for i in pairs(trinketClauses) do
		if trinketClauses[i]["All"] and not optionList.allClauseTable.args[i] then
			addToClauseList(optionList.allClauseTable, i)
		end
		if trinketClauses[i]["Melee"] and not optionList.meleeClauseTable.args[i] then
			addToClauseList(optionList.meleeClauseTable, i)
		end
		if trinketClauses[i]["Ranged"] and not optionList.rangedClauseTable.args[i] then
			addToClauseList(optionList.rangedClauseTable, i)
		end
		if trinketClauses[i]["Healer"] and not optionList.healerClauseTable.args[i] then
			addToClauseList(optionList.healerClauseTable, i)
		end
		if not trinketClauses[i]["All"] and not trinketClauses[i]["Melee"] and 
		   not trinketClauses[i]["Ranged"] and not trinketClauses[i]["Healer"] and
		   not optionList.disabledClauseTable.args[i] then
			addToClauseList(optionList.disabledClauseTable, i)
		end
	end
	
	local trinketClauses = ItemScore.cachedClauses or {}
	for i in pairs(optionList.availableClauses.args) do
		if not trinketClauses[i] then
			optionList.allClauseTable.args[i] = nil
		end
	end
	
	for i in pairs(trinketClauses) do
		if not optionList.availableClauses.args[i] then
			local options = {
				clause = {
					type = "input",
					name = "Clause",
					order = 5,
					arg = i,
					set = function(value) end,
					width = "full",
					get = function(info) return info.arg end, 
				},
			}
			
			optionList.availableClauses.args[i] = {
				name = i,
				type = "group",
				args = options,
			}
		end
	end
end

-- Handlers

function ItemScoreConfig:GetSelectedSet(info, value)
	-- return the selected set name
	return self.selectedSet
end

function ItemScoreConfig:SetSelectedSet(info, value)
	self.selectedSet = value
	
	self:UpdateStatTable()
	self:UpdateExampleText()
	self:UpdateSetLists()
end

function ItemScoreConfig:GetNewName(info, value)
	return self.newName
end

function ItemScoreConfig:SetNewName(info, value)
	self.newName = value
end

function ItemScoreConfig:CreateNewSet()
	if not self.newName or self.newName == '' then
		-- display error here
	else
		ItemScore:CreateNewSet(self.newName)
		self:SetSelectedSet(nil, self.newName)
		self:UpdateSetLists()
	end
end

function ItemScoreConfig:CopySet()
	if not self.newName or self.newName == '' then
		-- display error here
	elseif not self.selectedSet then
		-- display error here
	else
		ItemScore:CopySet(self.selectedSet, self.newName)
		self:SetSelectedSet(nil, self.newName)
		self:UpdateSetLists()
	end 
end

function ItemScoreConfig:RenameSet()
	if not self.newName or self.newName == '' then
		-- display error here
	elseif not self.selectedSet then
		-- display error here
	else
		ItemScore:RenameSet(self.selectedSet, self.newName)
		
		self.selectedSet = self.newName
		self:UpdateSetLists()
	end 
end

function ItemScoreConfig:DeleteSet()
	if not self.selectedSet then
		-- display error here
	else
		ItemScore:DeleteSet(self.selectedSet)
		
		self:SetSelectedSet()
		self:UpdateSetLists()
	end 
end

function ItemScoreConfig:SetScore(info, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot set value with no selected set")
	else
		ItemScore:SetScore(self.selectedSet, info.arg, value)
		self:UpdateStatTable()
	end 
end

function ItemScoreConfig:GetScore(info, value)
	if not self.selectedSet then
		-- display error here
		return 0
	else
		return ItemScore:GetScore(self.selectedSet, info.arg)
	end
end

function ItemScoreConfig:SetCap(info, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot set cap value with no selected set")
	else
		if value == "" then
			value = -1
		end
		ItemScore:SetCap(self.selectedSet, info.arg, value)
		self:UpdateStatTable()
	end 
end

function ItemScoreConfig:GetCap(info, value)
	if not self.selectedSet then
		-- display error here
		return ""
	else
		local cap = ItemScore:GetCap(self.selectedSet, info.arg)
		if cap == -1 then
			return ""
		else
			return cap
		end
	end
end

function ItemScoreConfig:AddStat(info, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot add stat with no selected set")
	else
		ItemScore:AddStat(self.selectedSet, info.arg)
		self:UpdateStatTable()
	end 
end

function ItemScoreConfig:RemoveStat(info, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot remove stat with no selected set")
	else
		ItemScore:RemoveStat(self.selectedSet, info.arg)
		self:UpdateStatTable()
	end 
end

function ItemScoreConfig:GetParent(info, value)
	-- return the selected set name
	if self.selectedSet then
		return ItemScore:GetParent(self.selectedSet)
	end
	
	return nil
end

function ItemScoreConfig:SetParent(info, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot set parent with no selected set")
	else
	    ItemScore:SetParent(self.selectedSet, value)
	end 
end

function ItemScoreConfig:SetEnabled(info, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot set display value with no selected set")
	else
		ItemScore:SetEnabled(self.selectedSet, value)
	end 
end

function ItemScoreConfig:GetEnabled(info, value)
	if not self.selectedSet then
		-- display error here
		return nil
	else
		return ItemScore:GetEnabled(self.selectedSet)
	end
end

function ItemScoreConfig:SetTrinketCalc(info, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot set display value with no selected set")
	else
		ItemScore:SetCalcTrinket(self.selectedSet, value)
	end 
end

function ItemScoreConfig:GetTrinketCalc(info, value)
	if not self.selectedSet then
		-- display error here
		return nil
	else
		return ItemScore:GetCalcTrinket(self.selectedSet)
	end
end

function ItemScoreConfig:SetPrecision(info, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot set precision value with no selected set")
	else
		ItemScore:SetPrecision(self.selectedSet, value)
		self:UpdateExampleText()
	end 
end

function ItemScoreConfig:GetPrecision(info, value)
	if not self.selectedSet then
		-- display error here
		return 0
	else
		return ItemScore:GetPrecision(self.selectedSet)
	end
end

function ItemScoreConfig:SetColour(info, r, g, b, a)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot set colour with no selected set")
	else
		ItemScore:SetColour(self.selectedSet, r, g, b)
	end 
end

function ItemScoreConfig:GetColour(info, value)
	if not self.selectedSet then
		-- display error here
		return 0,0,0,1
	else
		return ItemScore:GetColour(self.selectedSet)
	end
end

function ItemScoreConfig:SetPattern(info, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot set text with no selected set")
	else
		ItemScore:SetPattern(self.selectedSet, value)
		self:UpdateExampleText()
	end 
end

function ItemScoreConfig:GetPattern(info, value)
	if not self.selectedSet then
		-- display error here
		return ""
	else
		return ItemScore:GetPattern(self.selectedSet)
	end
end

function ItemScoreConfig:GetScoreSetCategories(info, name)
	if not self.selectedSet then
		return ""
	else
		return ItemScore:GetScoreSetCategory(self.selectedSet, trinketClauseCategories[name])
	end
end

function ItemScoreConfig:SetScoreSetCategories(info, name, value)
	if not self.selectedSet then
		DEFAULT_CHAT_FRAME:AddMessage("Cannot set text with no selected set")
	else
		ItemScore:SetScoreSetCategory(self.selectedSet, trinketClauseCategories[name], value)
	end 
end

function ItemScoreConfig:GetImportFormat(info, value)
	if not self.importFormat then
		self.importFormat = 1
	end
	return self.importFormat
end

function ItemScoreConfig:SetImportFormat(info, value)
	self.importFormat = value
	
	-- REVISIT - enable/disable name depedning on format
end

function ItemScoreConfig:GetImportName(info, value)
	if not self.importName then
		self.importName = ""
	end
	
	return self.importName
end

function ItemScoreConfig:SetImportName(info, value)
	self.importName = value
end

function ItemScoreConfig:GetImportCode(info, value)
	if not self.importCode then
		self.importCode = ""
	end
	
	return self.importCode
end

function ItemScoreConfig:SetImportCode(info, value)
	self.importCode = value
end

function ItemScoreConfig:ImportScoreSet()
	ItemScore:ParseTag(self.importName, importFormats[self.importFormat], self.importCode)
	self:UpdateSetLists()
end

function ItemScoreConfig:UpdateExportCode()
	self.exportCode = ItemScore:ExportSet(self.exportSet, importFormats[self.exportFormat])
end

function ItemScoreConfig:GetExportSet(info, value)
	return self.exportSet
end

function ItemScoreConfig:SetExportSet(info, value)
	self.exportSet = value
	self:UpdateExportCode()
end

function ItemScoreConfig:GetExportFormat(info, value)
	if not self.exportFormat then
		self.exportFormat = "AskMrRobot"
	end
	return self.exportFormat
end

function ItemScoreConfig:SetExportFormat(info, value)
	self.exportFormat = value
	self:UpdateExportCode()
end

function ItemScoreConfig:GetExportCode(info, value)
	if not self.exportCode then
		self.exportCode = ""
	end
	
	return self.exportCode
end

function ItemScoreConfig:AddClause(info, value)
	ItemScore:AddTrinketClause(value)
	self:UpdateClauseTable()
end

function ItemScoreConfig:RemoveClause(info, value)
	ItemScore:RemoveTrinketClause(info.arg)
	self:UpdateClauseTable()
end

function ItemScoreConfig:RenameClause(info, value)
	ItemScore:AddTrinketClause(value)
	ItemScore:RemoveTrinketClause(info.arg)
	self:UpdateClauseTable()
end

function ItemScoreConfig:GetClauseCategories(info, name)
	return ItemScore:GetTrinketClauseCategory(info.arg, trinketClauseCategories[name])
end

function ItemScoreConfig:SetClauseCategories(info, name, value)
	ItemScore:SetTrinketClauseCategory(info.arg, trinketClauseCategories[name], value)
	self:UpdateClauseTable()
end

function ItemScoreConfig:SetShowTrinketUptime(info, value)
	ItemScore:SetShowTrinketUptime(value)
end

function ItemScoreConfig:GetShowTrinketUptime(info, value)
	return ItemScore:GetShowTrinketUptime()
end

function ItemScoreConfig:SetShowTrinketEffect(info, value)
	ItemScore:SetShowTrinketEffect(value)
end

function ItemScoreConfig:GetShowTrinketEffect(info, value)
	return ItemScore:GetShowTrinketEffect()
end
